#
# spec file for package python-pytest-regressions
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-regressions
Version:        2.5.0
Release:        1.9
License:        MIT
Summary:        Python fixtures to write regression tests
URL:            https://github.com/ESSS/pytest-regressions
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/p/pytest-regressions/pytest-regressions-%{version}.tar.gz
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 6.2.0}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest-datadir >= 1.2.0}
# These could be added as build dep for testing but are commented to
# reduce the number of requirements.
# BuildRequires:  %%{python_module pandas}
# BuildRequires:  %%{python_module matplotlib}
# /SECTION
BuildRequires:  fdupes
Requires:       python-PyYAML
Requires:       python-pytest >= 6.2.0
Requires:       python-pytest-datadir >= 1.2.0
Suggests:       python-matplotlib
Suggests:       python-numpy
Suggests:       python-pandas
Suggests:       python-Pillow
BuildArch:      noarch

%python_subpackages

%description
Python fixtures to write regression tests.

%prep
%autosetup -p1 -n pytest-regressions-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# ignore tests that depends on matplotlib
donttest="test_image_regression"
# Requires python-pandas
donttest+=" or test_foo"
# Precision issues on i586 on SLE15
donttest+=" or (test_common_case and not test_common_case_)"
# Failing test on s390x
donttest+=" or test_different_data_types"
# Ignore tests that depends on python-pandas
%pytest --ignore tests/test_num_regression.py --ignore tests/test_dataframe_regression.py -k "not ($donttest)"

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/pytest_regressions*

%changelog
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  * Dropped support for EOL Python 3.6 and Python 3.7.
  * Added support for Python 3.11.
  * Make ``dataframe_regression`` compatible with classes inheriting
    from ``pandas.DataFrame``.
* Tue May 30 2023 Daniel Garcia <daniel.garcia@suse.com>
- Skip test_different_data_types because of s390x architecture issue.
* Mon May 29 2023 Markéta Machová <mmachova@suse.com>
- Skip test_common_case because of SLE15 i586 precision issue
* Thu May 25 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-pandas and python-matplotlib from BuildRequires
* Tue May  9 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.2:
  * Properly handle missing index ``0``.
  * Compatibility fix for pytest 6.2.
  * New ``--regen-all`` flag, which regenerates all files without
    failing the tests. Useful to regenerate all files in
    the test suite with a single run.
  * The public API is now fully type annotated.
  * ``pytest>=6.2`` is now required.
  * Properly handle empty and NaN values on
    num_regression and dataframe_regression.
  * New ``--with-test-class-names`` command-line flag to consider
    test class names when composing the expected and obtained
    data filenames. Needed when the same module contains
    different classes with the same method names.
  * New ``ndarrays_regression``, for comparing NumPy arrays with
    arbitrary shape.
  * Fix ``empty string bug`` on dataframe regression.
- drop np_num-deprecated.patch (upstream)
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Wed Jul 28 2021 Matej Cepl <mcepl@suse.com>
- Update to 2.2.0:
  - #45: num_regression.check now accepts any object that can be coerced
    to a 1d numpy array with numeric dtype (e.g. list, tuple, etc).
  - #35: New dataframe_regression fixture to check pandas DataFrames
    directly.
  - #34: Fix data_regression bug that creates empty file on serializing
    error.
- Add np_num-deprecated.patch to avoid tests failing on using deprecated
  data types (gh#ESSS/pytest-regressions#63).
* Thu Aug 20 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.1
